import type { ElementSymbol } from '..';
export { default as Bond } from './Bond.svelte';
export { default as Lattice } from './Lattice.svelte';
export { default as Structure } from './Structure.svelte';
export { default as StructureCard } from './StructureCard.svelte';
export { default as StructureLegend } from './StructureLegend.svelte';
export { default as StructureScene } from './StructureScene.svelte';
export type Species = {
    element: ElementSymbol;
    occu: number;
    oxidation_state: number;
};
export type Vector = [number, number, number];
export type NdVector = number[];
export type Site = {
    species: Species[];
    abc: Vector;
    xyz: Vector;
    label: string;
    properties: Record<string, unknown>;
};
export type PymatgenLattice = {
    matrix: [Vector, Vector, Vector];
    pbc: boolean[];
    a: number;
    b: number;
    c: number;
    alpha: number;
    beta: number;
    gamma: number;
    volume: number;
};
export type PymatgenStructure = {
    lattice: PymatgenLattice;
    sites: Site[];
    charge: number;
    id?: string;
};
export type IdStructure = PymatgenStructure & {
    id: string;
};
export declare function get_elem_amounts(structure: PymatgenStructure): Partial<Record<"K" | "H" | "He" | "Li" | "Be" | "B" | "C" | "N" | "O" | "F" | "Ne" | "Na" | "Mg" | "Al" | "Si" | "P" | "S" | "Cl" | "Ar" | "Ca" | "Sc" | "Ti" | "V" | "Cr" | "Mn" | "Fe" | "Co" | "Ni" | "Cu" | "Zn" | "Ga" | "Ge" | "As" | "Se" | "Br" | "Kr" | "Rb" | "Sr" | "Y" | "Zr" | "Nb" | "Mo" | "Tc" | "Ru" | "Rh" | "Pd" | "Ag" | "Cd" | "In" | "Sn" | "Sb" | "Te" | "I" | "Xe" | "Cs" | "Ba" | "La" | "Ce" | "Pr" | "Nd" | "Pm" | "Sm" | "Eu" | "Gd" | "Tb" | "Dy" | "Ho" | "Er" | "Tm" | "Yb" | "Lu" | "Hf" | "Ta" | "W" | "Re" | "Os" | "Ir" | "Pt" | "Au" | "Hg" | "Tl" | "Pb" | "Bi" | "Po" | "At" | "Rn" | "Fr" | "Ra" | "Ac" | "Th" | "Pa" | "U" | "Np" | "Pu" | "Am" | "Cm" | "Bk" | "Cf" | "Es" | "Fm" | "Md" | "No" | "Lr" | "Rf" | "Db" | "Sg" | "Bh" | "Hs" | "Mt" | "Ds" | "Rg" | "Cn" | "Nh" | "Fl" | "Mc" | "Lv" | "Ts" | "Og", number>>;
export declare function alphabetical_formula(structure: PymatgenStructure): string;
export declare const atomic_radii: Record<ElementSymbol, number>;
export declare const atomic_weights: {
    [k: string]: number;
};
export declare function get_elements(structure: PymatgenStructure): ElementSymbol[];
export declare function density(structure: PymatgenStructure, prec?: string): any;
export declare function euclidean_dist(p1: Vector, p2: Vector): number;
export declare function find_image_atoms(structure: PymatgenStructure, { tolerance }?: {
    tolerance?: number;
}): Array<[number, Vector]>;
export declare function symmetrize_structure(...args: Parameters<typeof find_image_atoms>): PymatgenStructure;
export declare function add(...vecs: NdVector[]): NdVector;
